@@ -123,7 +123,7 @@ def _ecc_decode_compressed_point(curve, compressed_point):
     y_order_map = {b"\x02": 0, b"\x03": 1}
     raw_x = compressed_point[1:]
     raw_x = to_bytes(raw_x)
-    x = int_from_bytes(raw_x, "big")
+    x = int_from_bytes(raw_x, "big")  # pylint: disable=not-callable
     raw_y = compressed_point[0]
     # In Python3, bytes index calls return int values rather than strings
     if isinstance(raw_y, six.integer_types):
