@@ -75,6 +75,8 @@ class _ClientConfig(object):
 
     :param source: Source data to encrypt or decrypt
     :type source: str, bytes, io.IOBase, or file
+    :param commitment_policy: The commitment policy to use during encryption and decryption
+    :type commitment_policy: aws_encryption_sdk.identifiers.CommitmentPolicy
     :param materials_manager: `CryptoMaterialsManager` from which to obtain cryptographic materials
         (either `materials_manager` or `key_provider` required)
     :type materials_manager: aws_encryption_sdk.materials_manager.base.CryptoMaterialsManager
@@ -732,7 +734,7 @@ class DecryptorConfig(_ClientConfig):
 
 
 class StreamDecryptor(_EncryptionStream):  # pylint: disable=too-many-instance-attributes
-    """Provides a streaming encryptor for encrypting a stream source.
+    """Provides a streaming decryptor for decrypting a stream source.
     Behaves as a standard file-like object.
 
     .. note::
